@@ -39,6 +39,13 @@ push @::global_suppressions,
      qr(WSREP: Action message in non-primary configuration from member [0-9]*),
      qr(WSREP: --wsrep-causal-reads=ON takes precedence over --wsrep-sync-wait=0. WSREP_SYNC_WAIT_BEFORE_READ is on),
      qr(WSREP: JOIN message from member .* in non-primary configuration. Ignored.),
+     qr|Query apply failed:*|,
+     qr(WSREP: Ignoring error*),
+     qr(WSREP: Failed to remove page file .*),
+     qr(WSREP: wsrep_sst_method is set to 'mysqldump' yet mysqld bind_address is set to .*),
+     qr|WSREP: Sending JOIN failed: -107 \(Transport endpoint is not connected\). Will retry in new primary component.|,
+     qr|WSREP: Trying to continue unpaused monitor|,
+     qr|WSREP: Wait for gtid returned error 3 while waiting for prior transactions to commit before setting position|,
    );
 
 bless { };
